==> openGion7.0.5.0_dev.zip: uap/webapps/ge/db/ORACLE/sql/install/01_TABLE/GE55S.sql <==
/****************************************************************************/
/* GE55 ( 出力先ﾏｽﾀ )                                                       */
/*                                                                          */
/* Created : 2018/09/28 16:03:20                                            */
/****************************************************************************/

CREATE TABLE GE55 (
   SYSTEM_ID        VARCHAR2 (  10 )                    NOT NULL            /*  10 ｼｽﾃﾑID       */
 , PRTID            VARCHAR2 (  20 )                    NOT NULL            /*  20 ﾌﾟﾘﾝﾀID      */
 , PRTNM            VARCHAR2 ( 100 )                                        /*  30 ﾌﾟﾘﾝﾀ名      */
 , PORTNM           VARCHAR2 (  30 )                                        /*  40 ﾎﾟｰﾄ名       */
 , COMMENTS         VARCHAR2 ( 500 )                                        /*  50 ｺﾒﾝﾄ         */
 , RELEASE_NOTES    VARCHAR2 ( 120 )                                        /*  60 ﾘﾘｰｽﾉｰﾄ      */
 , RDC_CODE         VARCHAR2 (  20 )                                        /*  70 設変番号     */
 , PRT_GRP          VARCHAR2 (  20 )                                        /*  80 ﾌﾟﾘﾝﾀｰｸﾞﾙｰﾌﾟ */
 , HOST_ID          VARCHAR2 (  50 )                                        /* 150 ﾎｽﾄ          */
 , FGJ              VARCHAR2 (   1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET            VARCHAR2 (  14 )                                        /* 820 登録日時     */
 , PGSET            VARCHAR2 (  10 )                                        /* 830 作成PG       */
 , PGPSET           VARCHAR2 (  10 )                                        /* 840 作成親PG     */
 , USRSET           VARCHAR2 (  10 )                                        /* 850 作成者       */
 , DYUPD            VARCHAR2 (  14 )                                        /* 860 更新日時     */
 , PGUPD            VARCHAR2 (  10 )                                        /* 870 更新PG       */
 , PGPUPD           VARCHAR2 (  10 )                                        /* 880 更新親PG     */
 , USRUPD           VARCHAR2 (  10 )                                        /* 890 更新者       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );

==> openGion7.4.0.0_dev.zip: uap/webapps/ge/db/ORACLE/sql/install/01_TABLE/GE55S.sql <==
/****************************************************************************/
/* GE55 ( 出力先ﾏｽﾀ )                                                       */
/*                                                                          */
/* Created : 2020/12/16 08:13:51                                            */
/****************************************************************************/

CREATE TABLE GE55 (
   SYSTEM_ID        VARCHAR2 (  10 )                    NOT NULL            /*  10 ｼｽﾃﾑID       */
 , PRTID            VARCHAR2 (  20 )                    NOT NULL            /*  20 ﾌﾟﾘﾝﾀID      */
 , PRTNM            VARCHAR2 ( 100 )                                        /*  30 ﾌﾟﾘﾝﾀ名      */
 , PORTNM           VARCHAR2 (  30 )                                        /*  40 ﾎﾟｰﾄ名       */
 , COMMENTS         VARCHAR2 ( 500 )                                        /*  50 ｺﾒﾝﾄ         */
 , RELEASE_NOTES    VARCHAR2 ( 120 )                                        /*  60 ﾘﾘｰｽﾉｰﾄ      */
 , RDC_CODE         VARCHAR2 (  20 )                                        /*  70 設変番号     */
 , PRT_GRP          VARCHAR2 (  20 )                                        /*  80 ﾌﾟﾘﾝﾀｰｸﾞﾙｰﾌﾟ */
 , HOST_ID          VARCHAR2 (  50 )                                        /* 150 ﾎｽﾄ          */
 , FGJ              VARCHAR2 (   1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET            VARCHAR2 (  14 )                                        /* 820 作成日時     */
 , PGSET            VARCHAR2 (  10 )                                        /* 830 作成PG       */
 , PGPSET           VARCHAR2 (  10 )                                        /* 840 作成親PG     */
 , USRSET           VARCHAR2 (  10 )                                        /* 850 作成者       */
 , DYUPD            VARCHAR2 (  14 )                                        /* 860 更新日時     */
 , PGUPD            VARCHAR2 (  10 )                                        /* 870 更新PG       */
 , PGPUPD           VARCHAR2 (  10 )                                        /* 880 更新親PG     */
 , USRUPD           VARCHAR2 (  10 )                                        /* 890 更新者       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );
